From 3b415fb8c025d7df95c47916984d8ef31c073db8 Mon Sep 17 00:00:00 2001
From: Wu Jianhua <jianhua.wu@intel.com>
Date: Mon, 28 Feb 2022 10:48:38 +0800
Subject: [PATCH 2/2] avutil/vulkan: print correct text for shader_vulkan
 filter

We don't need the strlen to get the size of string, for
there is a null terminated condition of C-style string.

And deal with the last line without line feed notation
to output correct shader text for shader_vulkan filter.

Signed-off-by: Wu Jianhua <jianhua.wu@intel.com>
---
 libavutil/vulkan.c | 15 ++++++++++-----
 1 file changed, 10 insertions(+), 5 deletions(-)

diff --git a/libavutil/vulkan.c b/libavutil/vulkan.c
index 403f0b1f27..0446e822af 100644
--- a/libavutil/vulkan.c
+++ b/libavutil/vulkan.c
@@ -829,19 +829,24 @@ void ff_vk_print_shader(void *ctx, FFVkSPIRVShader *shd, int prio)
     int line = 0;
     const char *p = shd->src.str;
     const char *start = p;
-    const size_t len = strlen(p);
 
     AVBPrint buf;
     av_bprint_init(&buf, 0, AV_BPRINT_SIZE_UNLIMITED);
 
-    for (int i = 0; i < len; i++) {
-        if (p[i] == '\n') {
+    while (*p) {
+        if (*p++ == '\n') {
             av_bprintf(&buf, "%i\t", ++line);
-            av_bprint_append_data(&buf, start, &p[i] - start + 1);
-            start = &p[i + 1];
+            av_bprint_append_data(&buf, start, p - start);
+            start = p;
         }
     }
 
+    /* Last line without '\n' */
+    if (p != start) {
+        av_bprintf(&buf, "%i\t", ++line);
+        av_bprintf(&buf, "%s\n", start);
+    }
+
     av_log(ctx, prio, "Shader %s: \n%s", shd->name, buf.str);
     av_bprint_finalize(&buf, NULL);
 }
-- 
2.32.0.windows.1

